@@ -52,8 +52,8 @@ func readMetric(m prometheus.Metric) MetricResult {
 
 func sanitizeQuery(q string) string {
 	q = strings.Join(strings.Fields(q), " ")
-	q = strings.Replace(q, "(", "\\(", -1)
-	q = strings.Replace(q, ")", "\\)", -1)
-	q = strings.Replace(q, "*", "\\*", -1)
+	q = strings.ReplaceAll(q, "(", "\\(")
+	q = strings.ReplaceAll(q, ")", "\\)")
+	q = strings.ReplaceAll(q, "*", "\\*")
 	return q
 }
