@@ -61,6 +61,18 @@ var (
 		"tls.insecure-skip-verify",
 		"Ignore certificate and server verification when using a tls connection.",
 	).Bool()
+	exporterLockTimeout = kingpin.Flag(
+		"exporter.lock_wait_timeout",
+		"Set a lock_wait_timeout (in seconds) on the connection to avoid long metadata locking.",
+	).Default("2").Int()
+	enableExporterLockTimeout = kingpin.Flag(
+		"exporter.enable_lock_wait_timeout",
+		"Enable the lock_wait_timeout MySQL connection parameter.",
+	).Default("true").Bool()
+	slowLogFilter = kingpin.Flag(
+		"exporter.log_slow_filter",
+		"Add a log_slow_filter to avoid slow query logging of scrapes. NOTE: Not supported by Oracle MySQL.",
+	).Default("false").Bool()
 	toolkitFlags = webflag.AddFlags(kingpin.CommandLine, ":9104")
 	c            = config.MySqlConfigHandler{
 		Config: &config.Config{},
@@ -104,6 +116,7 @@ var scrapers = map[collector.Scraper]bool{
 	collector.ScrapeHeartbeat{}:                           false,
 	collector.ScrapeSlaveHosts{}:                          false,
 	collector.ScrapeReplicaHost{}:                         false,
+	collector.ScrapeRocksDBPerfContext{}:                  false,
 }
 
 func filterScrapers(scrapers []collector.Scraper, collectParams []string) []collector.Scraper {
@@ -199,7 +212,11 @@ func newHandler(scrapers []collector.Scraper, logger *slog.Logger) http.HandlerF
 
 		registry := prometheus.NewRegistry()
 
-		registry.MustRegister(collector.New(ctx, dsn, filteredScrapers, logger))
+		registry.MustRegister(collector.New(ctx, dsn, filteredScrapers, logger,
+			collector.EnableLockWaitTimeout(*enableExporterLockTimeout),
+			collector.SetLockWaitTimeout(*exporterLockTimeout),
+			collector.SetSlowLogFilter(*slowLogFilter),
+		))
 
 		gatherers := prometheus.Gatherers{
 			prometheus.DefaultGatherer,
